@@ -31,9 +31,12 @@ UNBUILDABLE_IMAGES = {
     },
 
     'debian': {
+        "openvswitch-netcontrold",
+        # https://bugs.launchpad.net/kolla/+bug/2027668
     },
 
     'rocky': {
+        "collectd",              # Missing libpqos.so.4()(64bit)
         "hacluster-pcs",         # Missing crmsh package
         "nova-spicehtml5proxy",  # Missing spicehtml5 package
         "ovsdpdk",               # Not supported on CentOS
